@@ -74,6 +74,21 @@ class Tag(SubDir):
         task = loop.create_task(self.do_release(released, semaphore))
         task.add_done_callback(self.done_cb)
 
+    def _stable_path(self) -> Path:
+        return self._path / ".stable"
+
+    def is_stable(self) -> bool:
+        return self._stable_path().is_file()
+
+    def set_stable(self, stable: bool):
+        if not self._path.is_dir():
+            raise FileNotFoundError()
+        path = self._stable_path()
+        if stable:
+            path.touch()
+        elif path.is_file():
+            path.unlink()
+
     def done_cb(self, task):
         if task.cancelled():
             return
